# Generated by Django 2.1.4 on 2018-12-27 08:50

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('individuals', '__first__'),
        ('auth', '0009_alter_user_last_name_max_length'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Case',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(choices=[('new', 'New'), ('solved', 'Solved'), ('closed', 'Closed')], default='new', max_length=100)),
                ('name', models.CharField(blank=True, max_length=600)),
                ('description', models.TextField(blank=True, null=True)),
                ('case_groups', models.ManyToManyField(blank=True, related_name='case_groups', to='auth.Group', verbose_name='Groups of Cases')),
                ('cases', models.ManyToManyField(blank=True, related_name='cases', to='individuals.Individual')),
                ('children', models.ManyToManyField(blank=True, related_name='children', to='individuals.Individual')),
                ('control_groups', models.ManyToManyField(blank=True, related_name='control_groups', to='auth.Group', verbose_name='Groups of Controls')),
                ('controls', models.ManyToManyField(blank=True, related_name='controls', to='individuals.Individual', verbose_name='Controls')),
                ('father', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='father', to='individuals.Individual')),
                ('mother', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='mother', to='individuals.Individual')),
                ('shared_with_groups', models.ManyToManyField(blank=True, related_name='shared_with', to='auth.Group')),
                ('shared_with_users', models.ManyToManyField(blank=True, related_name='shared_with', to=settings.AUTH_USER_MODEL)),
                ('user', models.ForeignKey(editable=False, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
