# Generated by Django 2.1.4 on 2018-12-27 08:50

from django.conf import settings
import django.contrib.postgres.fields.jsonb
from django.db import migrations, models
import django.db.models.deletion
import files.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='File',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=600)),
                ('size', models.BigIntegerField(blank=True, null=True)),
                ('file_type', models.TextField(blank=True, null=True)),
                ('extension', models.TextField(blank=True, null=True)),
                ('location', models.TextField(blank=True, null=True)),
                ('local_file', models.FileField(blank=True, help_text='File Format: VCF', max_length=600, upload_to=files.models.File.get_upload_path)),
                ('remote_location', models.TextField(blank=True, null=True)),
                ('url', models.TextField(blank=True, null=True)),
                ('status', models.TextField(blank=True, null=True)),
                ('last_output', models.TextField(blank=True, null=True)),
                ('params', django.contrib.postgres.fields.jsonb.JSONField(blank=True, null=True)),
                ('md5', models.TextField(blank=True, null=True)),
                ('last_modified', models.DateTimeField(blank=True, null=True)),
                ('creation_date', models.DateTimeField(auto_now_add=True, null=True)),
                ('modified_date', models.DateTimeField(auto_now=True, null=True)),
                ('user', models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
